@@ -18,25 +18,24 @@ from .src import (
     PositionDecisionCategoryWriter,
     PositionNotice,
     get_annex_y_axis,
-    get_endpageline,
-    get_header_terminal,
+    get_header_line,
     get_page_and_img,
+    get_page_num,
+    get_terminal_page_pos,
 )
 
 
 @dataclass
 class DecisionPage:
-    """Each `page_num` should have a `body`, and optionally an `annex`.
+    """Metadata of a single page of the pdf file parsed via `get_decision()`
 
-    `lines`  are segments of the body's text (in the given page
-    num); segments are split based on regex.
-
-    `footnotes` refer to each item in the annex's text (in the given page
-    num); footnote splitting is based on regex.
-
-
-    Returns:
-        DecisionPage: Page with individual components mapped out.
+    Field | Description
+    --:|:--
+    `page_num` | The page number of the Decision page
+    `body` | The main content above the annex, if existing
+    `lines` | Segments of the `body`'s text in the given `page_num`
+    `annex` | Portion of page containing the footnotes; some pages are annex-free
+    `footnotes` | Each footnote item in the `annex`'s text in the given `page_num`
     """
 
     page_num: int
@@ -56,8 +55,8 @@ class DecisionPage:
         path: Path,
         page_num: int = 2,
         terminal_y: int | None = None,
-    ) -> Self:
-        """Each non-first page follows a certain format.
+    ) -> Self | None:
+        """Each `page_num` should have a `body`, and optionally an `annex`
 
         Args:
             path (Path): Path to the pdf file.
@@ -66,35 +65,58 @@ class DecisionPage:
                 The y-axis point of the terminal page. Defaults to None.
 
         Returns:
-            Self: A component page element of a Decision.
+            Self: Page with individual components mapped out.
         """
         if page_num <= 1:
             raise Exception("Must not be the first page.")
+
         page, im = get_page_and_img(path, page_num - 1)
-        cut = {"page": page, "x0": SIDE_MARGIN, "x1": page.width - SIDE_MARGIN}
-        head = get_header_terminal(im, page)
-        if not head:
+
+        # preflight check to determine if blank
+        if len(page.extract_text()) < 100:
+            return None
+
+        # the header line determines the start of the body proper
+        header_line = get_header_line(im, page)
+        if not header_line:
             raise Exception("Could not find header.")
 
-        e1, e2 = get_annex_y_axis(im, page)
-        annex = PageCut(**cut, y0=e1, y1=e2).slice if e2 else None
+        # necessary because of blank pages
+        extracted_page_num = get_page_num(page, header_line) or 0
+
+        # prepare common slicing borders
+        cut = {"page": page, "x0": SIDE_MARGIN, "x1": page.width - SIDE_MARGIN}
+
+        # get body_end_line and terminal_line for annex and body vertical borders
+        body_end_line, terminal_line = get_annex_y_axis(im, page)
+        annex = None
+        if terminal_line:
+            annex = PageCut(**cut, y0=body_end_line, y1=terminal_line).slice
         if terminal_y:
-            e1 = terminal_y
-        return cls(
-            body=PageCut(**cut, y0=head, y1=e1).slice,
-            annex=annex,
-            page_num=page_num,
-        )
+            body_end_line = terminal_y
+        body = PageCut(**cut, y0=header_line, y1=body_end_line).slice
+
+        return cls(body=body, annex=annex, page_num=extracted_page_num)
 
 
 @dataclass
 class Decision:
-    """Metadata of a given pdf Decision by using `.convert()`."""
+    """Metadata of a pdf file parsed via `get_decision()`
+
+    Field | Description
+    --:|:--
+    header | The top portion of the page, usually excluded from metadata
+    composition | The composition of the Supreme Court that decided the case
+    category | When available, whether the case is a "Decision" or a "Resolution"
+    writer | When available, the writer of the case
+    notice | When True, means that there is no `category` available
+    pages | A list of [Decision Pages with bodies/annexes][decision-page]
+    """
 
     header: CroppedPage
     composition: CourtCompositionChoices
-    writer: str | None = None
     category: DecisionCategoryChoices | None = None
+    writer: str | None = None
     notice: bool = False
     pages: list[DecisionPage] = field(default_factory=list)
 
@@ -161,7 +183,7 @@ class Decision:
     def make_next_pages(self, path: Path, last_num: int, last_y: int) -> Self:
         """After the first page is created, add subsequent pages taking into
         account the terminal page and line. When the terminal page `last_num`
-        is reached, stop the for loop.
+        is reached, stop the for-loop.
 
         Args:
             path (Path): Path to the pdf file.
@@ -170,15 +192,18 @@ class Decision:
 
         Returns:
             Self: The Decision instance containing any added pages from
-            the for loop.
+                the for loop.
         """
         for page in pdfplumber.open(path).pages:
             if (num := page.page_number) != 1:
                 if num == last_num:
-                    self.pages.append(DecisionPage.extract(path, num, last_y))
+                    if page_valid := DecisionPage.extract(path, num, last_y):
+                        self.pages.append(page_valid)
+                        page.pdf.close()
                     break
                 else:
-                    self.pages.append(DecisionPage.extract(path, num))
+                    if page_valid := DecisionPage.extract(path, num):
+                        self.pages.append(page_valid)
         return self
 
 
@@ -186,7 +211,7 @@ def get_decision(path: Path) -> Decision:
     """From a pdf file, get metadata filled Decision with pages
     cropped into bodies and annexes until the terminal page.
 
-    Example:
+    Examples:
         >>> from pathlib import Path
         >>> x = Path().cwd() / "tests" / "data" / "decision.pdf"
         >>> decision = get_decision(x)
@@ -209,9 +234,13 @@ def get_decision(path: Path) -> Decision:
     """  # noqa: E501
     page, im = get_page_and_img(path, 0)
     if not (comp := PositionCourtComposition.extract(im)):
+        page.pdf.close()
         raise Exception(f"No court composition detected {path=}")
     if not (caso := Decision.make_start_page(page, im, comp)):
+        page.pdf.close()
         raise Exception(f"First page unprocessed {path=}")
-    if not (terminal := get_endpageline(path)):
+    if not (page_pos := get_terminal_page_pos(path)):
+        page.pdf.close()
         raise Exception(f"No terminal detected {path=}")
-    return caso.make_next_pages(path, terminal[0], terminal[1])
+    decision = caso.make_next_pages(path, page_pos[0], page_pos[1])
+    return decision
